@@ -80,6 +80,9 @@ class InferFeatureAttributesDataFrame(InferFeatureAttributesBase):
         # Keep track of any features that use UTC offsets, as these could lead
         # to unexpected results due to daylight savings time in some time zones
         self.utc_offset_features = []
+        # Keep track of any features that we detected to be datetimes but were
+        # not in ISO8601 format
+        self.unknown_datetime_features = []
 
     def __call__(self, **kwargs) -> SingleTableFeatureAttributes:
         """Process and return feature attributes."""
@@ -115,6 +118,7 @@ class InferFeatureAttributesDataFrame(InferFeatureAttributesBase):
             }
 
             self.emit_time_zone_warnings(missing_tz_features, utc_offset_features)
+            self.emit_unknown_datetime_warnings(self.unknown_datetime_features)
 
             return SingleTableFeatureAttributes(
                 feature_attributes=feature_attributes, params=kwargs,
@@ -124,6 +128,7 @@ class InferFeatureAttributesDataFrame(InferFeatureAttributesBase):
         else:
             feature_attributes = self._process(**kwargs)
             self.emit_time_zone_warnings(self.missing_tz_features, self.utc_offset_features)
+            self.emit_unknown_datetime_warnings(self.unknown_datetime_features)
             return SingleTableFeatureAttributes(
                 feature_attributes, params=kwargs,
                 unsupported=self.unsupported
@@ -235,7 +240,7 @@ class InferFeatureAttributesDataFrame(InferFeatureAttributesBase):
                 return FeatureType.STRING, {}
 
             else:
-                first_non_null = self._get_first_non_null(feature_name)
+                first_non_null = next((x for x in self.data[feature_name].dropna() if str(x).strip()), None)
                 # DataFrames may use 'object' dtype for strings, detect
                 # string columns by checking the type of the data
                 if isinstance(first_non_null, str):
@@ -243,25 +248,37 @@ class InferFeatureAttributesDataFrame(InferFeatureAttributesBase):
                     if re.match(TIME_PATTERN, first_non_null) or re.match(SIMPLE_TIME_PATTERN,
                                                                           first_non_null):
                         return FeatureType.TIME, {}
+                    # explicitly declared formatted_date_time/time; don't try to guess
+                    if getattr(self, 'datetime_feature_formats', {}).get(feature_name) is not None:
+                        return FeatureType.STRING, {}  # Could be datetime or time-only; let base.py figure it out
                     try:
+                        # If the feature looks like a date or datetime, but it's not in ISO8601 format,
+                        # handle it as a string to avoid ambiguity.
                         converted_dtype = pd.to_datetime(pd.Series([first_non_null])).dtype
+                        converted_val = pd.to_datetime(first_non_null)
+                        if not self._is_iso8601_datetime_column(feature_name):
+                            self.unknown_datetime_features.append(feature_name)
+                            return FeatureType.STRING, {}
                         # Unfortunately, Pandas does not differentiate between datetimes and "pure" dates.
                         # If the below code executes, that means Pandas recognizes the value as a datetime,
                         # but we now need to check if the 'time' component is zero. If so, we can cast to
                         # a Numpy datetime64[D] dtype.
-                        converted_val = pd.to_datetime(first_non_null)
-                        # If the feature looks like a date or datetime, but it's not in ISO8601 format,
-                        # handle it as a string to avoid ambiguity.
-                        if not self._is_iso8601_datetime_column(feature_name):
-                            warnings.warn(f"Feature '{feature_name}' appears to be a datetime, but we cannot assume "
-                                          "its format. Please provide one using `datetime_feature_formats`. "
-                                          "Otherwise, this feature will be treated as a nominal string.")
-                            return FeatureType.STRING, {}
-                        if converted_val.time() == pd.Timestamp(0).time() and converted_val.tz is None:
+                        #
+                        # However, we need to be careful with this -- if the user has a datetime feature of the format
+                        # '%y-%m-%d' for example, the `to_datetime()` conversion above will add an empty time component
+                        # as previously described. But, if the user has a datetime feature that *actually* has an empty
+                        # time component in the string -- say, '%y-%m-%dT00:00:00' -- we must respect the original
+                        # format even if it is intended to be a date-only feature.
+                        if all([converted_val.time() == pd.Timestamp(0).time(),
+                                converted_val.tz is None,
+                                # Ensure there is no time component in the unconverted string
+                                'T' not in first_non_null,
+                                '00:00:00' not in first_non_null]):
                             converted_dtype = np.datetime64(converted_val, 'D').dtype
-                        typing_info = {}
+                        # Specify an original_type here to ensure the DataFrame is unchanged during deserialization
+                        typing_info = {'original_type': FeatureType.STRING}
                         if converted_dtype in ['datetime64[Y]', 'datetime64[M]', 'datetime64[D]']:
-                            return FeatureType.DATE, {}
+                            return FeatureType.DATE, typing_info
                         elif isinstance(converted_dtype, pd.DatetimeTZDtype) or getattr(converted_dtype.tz):
                             if isinstance(converted_dtype.tz, pytz.BaseTzInfo) and converted_dtype.tz.zone:
                                 # If using a named time zone capture it, otherwise
